Package 'ufmgthesis'

Title: UFMG's Quarto Templates for Writing Academic Documents
Description: Creates Quarto-based project templates for writing academic documents (Monographs, Dissertations and Theses) for UFMG students.
Authors: Fabio Demarqui [aut, cre]
Maintainer: Fabio Demarqui <[email protected]>
License: MIT + file LICENSE
Version: 0.0.1
Built: 2026-05-10 08:53:01 UTC
Source: https://github.com/fndemarqui/ufmgthesis

Help Index


Create a new ufmgthesis Quarto project from the package template

Description

Create a new ufmgthesis Quarto project from the package template

Usage

create_template(path = "ufmgthesis", open = TRUE, ...)

Arguments

path

Path to create the project in (will be created if missing).

open

If TRUE, opens the directory in RStudio (if available).

...

further arguments passed to other methods.